@@ -140,7 +140,10 @@ class ObjectDetectionRawResult:
         """Convert the detection results to a JSON serializable format."""
         results = []
         for bounding_box, score, label in zip(
-            self.detection_boxes, self.detection_scores, self.detection_classes
+            self.detection_boxes,
+            self.detection_scores,
+            self.detection_classes,
+            strict=True,
         ):
             label_int = int(label)
             label_str = self.label_names[label_int]
@@ -166,12 +169,12 @@ def apply_nms(
 
     We use `NMSBoxes` from the openCV library to perform NMS.
 
-    :param bboxes: The bounding boxes in format [y_min, x_min, y_max, x_max], in relative
-        coordinates. Shape: (N, 4)
+    :param bboxes: The bounding boxes in format [y_min, x_min, y_max, x_max],
+        in relative coordinates. Shape: (N, 4)
     :param scores: The confidence scores. Shape: (N,)
     :param classes: The class labels, as an int array. Shape: (N,)
-    :param threshold: The confidence threshold to use to filter out the bounding boxes.
-        Shape: (N,)
+    :param threshold: The confidence threshold to use to filter out the
+        bounding boxes. Shape: (N,)
     :param nms_threshold: The NMS threshold to use.
     :param nms_eta: The NMS eta to use.
     :return: bounding boxes, scores, classes after NMS
@@ -329,7 +332,8 @@ class ObjectDetector:
 
         if len(response.raw_output_contents) != 1:
             raise ValueError(
-                f"expected 1 raw output content, got {len(response.raw_output_contents)}"
+                "expected 1 raw output content, got "
+                f"{len(response.raw_output_contents)}"
             )
 
         if nms_threshold is None:
